@@ -118,30 +118,19 @@ def send_sms():
             service_code=SERVICE_CODE
             )
     else:
-        if (
-            (json_doc.get("msisdn")).startswith("34")
-            or (json_doc.get("msisdn")).startswith("39")
-            or (json_doc.get("msisdn")).startswith("034")
-            or (json_doc.get("msisdn")).startswith("039")
-            or (json_doc.get("msisdn")).startswith("26134")
-            or (json_doc.get("msisdn")).startswith("26139")
-        ):
-            connection.close()
-            pass
-        else:
-            channel = connection.channel()
-            channel.exchange_declare(
-                exchange='sendsms',
-                exchange_type='topic'
-                )
-            # déclaration idempotente: pas grave si l'exchange existe déjà
-            channel.basic_publish(
-                exchange='sendsms',
-                routing_key=queue,
-                body=json.dumps(document),
-                properties=pika.BasicProperties(delivery_mode=2)
-                )
-            connection.close()
+        channel = connection.channel()
+        channel.exchange_declare(
+            exchange='sendsms',
+            exchange_type='topic'
+            )
+        # déclaration idempotente: pas grave si l'exchange existe déjà
+        channel.basic_publish(
+            exchange='sendsms',
+            routing_key=queue,
+            body=json.dumps(document),
+            properties=pika.BasicProperties(delivery_mode=2)
+            )
+        connection.close()
         return success(service_code=SERVICE_CODE)
 
 
